==> jc-1.4.0.tar.gz: java/io/LineNumberInputStream.h <==
// public class java.io.LineNumberInputStream

// class file dependencies
// @dep_class 455accfa535f5dfe java_io_FilterInputStream
// @dep_class 66aea4d152614ac4 java_io_InputStream
// @dep_class 7e8bb67d8869be7 java_io_LineNumberInputStream
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_io_FilterInputStream

#include "java/io/FilterInputStream.h"

#ifndef _JC_java_io_LineNumberInputStream_H_
#define _JC_java_io_LineNumberInputStream_H_

// Forward structure declarations
struct _jc_java_io_InputStream$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_io_LineNumberInputStream$sub_refs	_jc_java_io_LineNumberInputStream$sub_refs;
typedef struct _jc_java_io_LineNumberInputStream$sub_nonrefs	_jc_java_io_LineNumberInputStream$sub_nonrefs;
typedef struct _jc_java_io_LineNumberInputStream$refs	_jc_java_io_LineNumberInputStream$refs;
typedef struct _jc_java_io_LineNumberInputStream$nonrefs	_jc_java_io_LineNumberInputStream$nonrefs;
typedef struct _jc_java_io_LineNumberInputStream$object	_jc_java_io_LineNumberInputStream$object;

typedef const struct _jc_java_io_LineNumberInputStream$vmethods	_jc_java_io_LineNumberInputStream$vmethods;
typedef const struct _jc_java_io_LineNumberInputStream$vtable	_jc_java_io_LineNumberInputStream$vtable;
typedef const struct _jc_java_io_LineNumberInputStream$vtype	_jc_java_io_LineNumberInputStream$vtype;

// Constructors
extern void _jc_java_io_LineNumberInputStream$method$_init$3887600c17c5e554(_jc_env *, struct _jc_java_io_LineNumberInputStream$object *, struct _jc_java_io_InputStream$object *);

// Virtual methods
extern jint _jc_java_io_LineNumberInputStream$method$available$81975cc608605037(_jc_env *, struct _jc_java_io_LineNumberInputStream$object *);
extern jint _jc_java_io_LineNumberInputStream$method$getLineNumber$fae6c5f943e25d60(_jc_env *, struct _jc_java_io_LineNumberInputStream$object *);
extern void _jc_java_io_LineNumberInputStream$method$mark$422af117ab27d9db(_jc_env *, struct _jc_java_io_LineNumberInputStream$object *, jint);
extern jint _jc_java_io_LineNumberInputStream$method$read$1a981297cb524963(_jc_env *, struct _jc_java_io_LineNumberInputStream$object *);
extern jint _jc_java_io_LineNumberInputStream$method$read$e6b6c87b9f256783(_jc_env *, struct _jc_java_io_LineNumberInputStream$object *, struct _jc_byte_array *, jint, jint);
extern void _jc_java_io_LineNumberInputStream$method$reset$229a80b3e8394a0f(_jc_env *, struct _jc_java_io_LineNumberInputStream$object *);
extern void _jc_java_io_LineNumberInputStream$method$setLineNumber$deb8494b02044268(_jc_env *, struct _jc_java_io_LineNumberInputStream$object *, jint);
extern jlong _jc_java_io_LineNumberInputStream$method$skip$4e431136b5c4614a(_jc_env *, struct _jc_java_io_LineNumberInputStream$object *, jlong);
extern void _jc_java_io_LineNumberInputStream$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_java_io_LineNumberInputStream$object *);

// Virtual method descriptors
extern _jc_method _jc_java_io_LineNumberInputStream$method_info$available$81975cc608605037;
extern _jc_method _jc_java_io_LineNumberInputStream$method_info$getLineNumber$fae6c5f943e25d60;
extern _jc_method _jc_java_io_LineNumberInputStream$method_info$mark$422af117ab27d9db;
extern _jc_method _jc_java_io_LineNumberInputStream$method_info$read$1a981297cb524963;
extern _jc_method _jc_java_io_LineNumberInputStream$method_info$read$e6b6c87b9f256783;
extern _jc_method _jc_java_io_LineNumberInputStream$method_info$reset$229a80b3e8394a0f;
extern _jc_method _jc_java_io_LineNumberInputStream$method_info$setLineNumber$deb8494b02044268;
extern _jc_method _jc_java_io_LineNumberInputStream$method_info$skip$4e431136b5c4614a;
extern _jc_method _jc_java_io_LineNumberInputStream$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_java_io_LineNumberInputStream$vmethods {
	jint	(*available$81975cc608605037)(_jc_env *, struct _jc_java_io_LineNumberInputStream$object *);
	jint	(*getLineNumber$fae6c5f943e25d60)(_jc_env *, struct _jc_java_io_LineNumberInputStream$object *);
	void	(*mark$422af117ab27d9db)(_jc_env *, struct _jc_java_io_LineNumberInputStream$object *, jint);
	jint	(*read$1a981297cb524963)(_jc_env *, struct _jc_java_io_LineNumberInputStream$object *);
	jint	(*read$e6b6c87b9f256783)(_jc_env *, struct _jc_java_io_LineNumberInputStream$object *, struct _jc_byte_array *, jint, jint);
	void	(*reset$229a80b3e8394a0f)(_jc_env *, struct _jc_java_io_LineNumberInputStream$object *);
	void	(*setLineNumber$deb8494b02044268)(_jc_env *, struct _jc_java_io_LineNumberInputStream$object *, jint);
	jlong	(*skip$4e431136b5c4614a)(_jc_env *, struct _jc_java_io_LineNumberInputStream$object *, jlong);
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_java_io_LineNumberInputStream$object *);
};

// Vtable
struct _jc_java_io_LineNumberInputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_InputStream$vmethods	java_io_InputStream;
	_jc_java_io_FilterInputStream$vmethods	java_io_FilterInputStream;
	_jc_java_io_LineNumberInputStream$vmethods	java_io_LineNumberInputStream;
};

// Vtype
struct _jc_java_io_LineNumberInputStream$vtype {
	_jc_type			type;
	_jc_java_io_LineNumberInputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_io_LineNumberInputStream$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_io_LineNumberInputStream$refs {
    _jc_java_io_LineNumberInputStream$sub_refs	java_io_LineNumberInputStream;
    _jc_java_io_FilterInputStream$sub_refs	java_io_FilterInputStream;
    _jc_java_io_InputStream$sub_refs	java_io_InputStream;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_io_LineNumberInputStream$sub_nonrefs {
	jint	lineNumber;
	jint	markLineNumber;
	jboolean	justReadReturnChar;
};

// Non-reference instance fields (object)
struct _jc_java_io_LineNumberInputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_InputStream$sub_nonrefs	java_io_InputStream;
    _jc_java_io_FilterInputStream$sub_nonrefs	java_io_FilterInputStream;
    _jc_java_io_LineNumberInputStream$sub_nonrefs	java_io_LineNumberInputStream;
};

// Object instance structure
struct _jc_java_io_LineNumberInputStream$object {
	_jc_java_io_LineNumberInputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_java_io_LineNumberInputStream$vtype	*vtype;
	_jc_java_io_LineNumberInputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_io_LineNumberInputStream$vtype _jc_java_io_LineNumberInputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_io_LineNumberInputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_io_LineNumberInputStream$class_object;

#endif	/* _JC_java_io_LineNumberInputStream_H_ */

==> jc-1.4.6.tar.gz: java/io/LineNumberInputStream.h <==
// public class java.io.LineNumberInputStream

// class file dependencies
// @dep_class 455accfa535f5dfe java_io_FilterInputStream
// @dep_class 66aea4d152614ac4 java_io_InputStream
// @dep_class 7e8bb67d8869be7 java_io_LineNumberInputStream
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_io_FilterInputStream

#include "java/io/FilterInputStream.h"

#ifndef _JC_java_io_LineNumberInputStream_H_
#define _JC_java_io_LineNumberInputStream_H_

// Forward structure declarations
struct _jc_java_io_InputStream$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_io_LineNumberInputStream$sub_refs	_jc_java_io_LineNumberInputStream$sub_refs;
typedef struct _jc_java_io_LineNumberInputStream$sub_nonrefs	_jc_java_io_LineNumberInputStream$sub_nonrefs;
typedef struct _jc_java_io_LineNumberInputStream$refs	_jc_java_io_LineNumberInputStream$refs;
typedef struct _jc_java_io_LineNumberInputStream$nonrefs	_jc_java_io_LineNumberInputStream$nonrefs;
typedef struct _jc_java_io_LineNumberInputStream$object	_jc_java_io_LineNumberInputStream$object;

typedef const struct _jc_java_io_LineNumberInputStream$vmethods	_jc_java_io_LineNumberInputStream$vmethods;
typedef const struct _jc_java_io_LineNumberInputStream$vtable	_jc_java_io_LineNumberInputStream$vtable;
typedef const struct _jc_java_io_LineNumberInputStream$vtype	_jc_java_io_LineNumberInputStream$vtype;

// Constructors
extern void _jc_java_io_LineNumberInputStream$method$_init$3887600c17c5e554(_jc_env *, struct _jc_java_io_LineNumberInputStream$object *, struct _jc_java_io_InputStream$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_java_io_LineNumberInputStream$method$available$81975cc608605037(_jc_env *, struct _jc_java_io_LineNumberInputStream$object *) _JC_JCNI_ATTR;
extern jint _jc_java_io_LineNumberInputStream$method$getLineNumber$fae6c5f943e25d60(_jc_env *, struct _jc_java_io_LineNumberInputStream$object *) _JC_JCNI_ATTR;
extern void _jc_java_io_LineNumberInputStream$method$mark$422af117ab27d9db(_jc_env *, struct _jc_java_io_LineNumberInputStream$object *, jint) _JC_JCNI_ATTR;
extern jint _jc_java_io_LineNumberInputStream$method$read$1a981297cb524963(_jc_env *, struct _jc_java_io_LineNumberInputStream$object *) _JC_JCNI_ATTR;
extern jint _jc_java_io_LineNumberInputStream$method$read$e6b6c87b9f256783(_jc_env *, struct _jc_java_io_LineNumberInputStream$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;
extern void _jc_java_io_LineNumberInputStream$method$reset$229a80b3e8394a0f(_jc_env *, struct _jc_java_io_LineNumberInputStream$object *) _JC_JCNI_ATTR;
extern void _jc_java_io_LineNumberInputStream$method$setLineNumber$deb8494b02044268(_jc_env *, struct _jc_java_io_LineNumberInputStream$object *, jint) _JC_JCNI_ATTR;
extern jlong _jc_java_io_LineNumberInputStream$method$skip$4e431136b5c4614a(_jc_env *, struct _jc_java_io_LineNumberInputStream$object *, jlong) _JC_JCNI_ATTR;
extern void _jc_java_io_LineNumberInputStream$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_java_io_LineNumberInputStream$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_io_LineNumberInputStream$method_info$available$81975cc608605037;
extern _jc_method _jc_java_io_LineNumberInputStream$method_info$getLineNumber$fae6c5f943e25d60;
extern _jc_method _jc_java_io_LineNumberInputStream$method_info$mark$422af117ab27d9db;
extern _jc_method _jc_java_io_LineNumberInputStream$method_info$read$1a981297cb524963;
extern _jc_method _jc_java_io_LineNumberInputStream$method_info$read$e6b6c87b9f256783;
extern _jc_method _jc_java_io_LineNumberInputStream$method_info$reset$229a80b3e8394a0f;
extern _jc_method _jc_java_io_LineNumberInputStream$method_info$setLineNumber$deb8494b02044268;
extern _jc_method _jc_java_io_LineNumberInputStream$method_info$skip$4e431136b5c4614a;
extern _jc_method _jc_java_io_LineNumberInputStream$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_java_io_LineNumberInputStream$vmethods {
	jint	(*available$81975cc608605037)(_jc_env *, struct _jc_java_io_LineNumberInputStream$object *) _JC_JCNI_ATTR;
	jint	(*getLineNumber$fae6c5f943e25d60)(_jc_env *, struct _jc_java_io_LineNumberInputStream$object *) _JC_JCNI_ATTR;
	void	(*mark$422af117ab27d9db)(_jc_env *, struct _jc_java_io_LineNumberInputStream$object *, jint) _JC_JCNI_ATTR;
	jint	(*read$1a981297cb524963)(_jc_env *, struct _jc_java_io_LineNumberInputStream$object *) _JC_JCNI_ATTR;
	jint	(*read$e6b6c87b9f256783)(_jc_env *, struct _jc_java_io_LineNumberInputStream$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;
	void	(*reset$229a80b3e8394a0f)(_jc_env *, struct _jc_java_io_LineNumberInputStream$object *) _JC_JCNI_ATTR;
	void	(*setLineNumber$deb8494b02044268)(_jc_env *, struct _jc_java_io_LineNumberInputStream$object *, jint) _JC_JCNI_ATTR;
	jlong	(*skip$4e431136b5c4614a)(_jc_env *, struct _jc_java_io_LineNumberInputStream$object *, jlong) _JC_JCNI_ATTR;
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_java_io_LineNumberInputStream$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_io_LineNumberInputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_InputStream$vmethods	java_io_InputStream;
	_jc_java_io_FilterInputStream$vmethods	java_io_FilterInputStream;
	_jc_java_io_LineNumberInputStream$vmethods	java_io_LineNumberInputStream;
};

// Vtype
struct _jc_java_io_LineNumberInputStream$vtype {
	_jc_type			type;
	_jc_java_io_LineNumberInputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_io_LineNumberInputStream$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_io_LineNumberInputStream$refs {
    _jc_java_io_LineNumberInputStream$sub_refs	java_io_LineNumberInputStream;
    _jc_java_io_FilterInputStream$sub_refs	java_io_FilterInputStream;
    _jc_java_io_InputStream$sub_refs	java_io_InputStream;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_io_LineNumberInputStream$sub_nonrefs {
	jint	lineNumber;
	jint	markLineNumber;
	jboolean	justReadReturnChar;
};

// Non-reference instance fields (object)
struct _jc_java_io_LineNumberInputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_InputStream$sub_nonrefs	java_io_InputStream;
    _jc_java_io_FilterInputStream$sub_nonrefs	java_io_FilterInputStream;
    _jc_java_io_LineNumberInputStream$sub_nonrefs	java_io_LineNumberInputStream;
};

// Object instance structure
struct _jc_java_io_LineNumberInputStream$object {
	_jc_java_io_LineNumberInputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_java_io_LineNumberInputStream$vtype	*vtype;
	_jc_java_io_LineNumberInputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_io_LineNumberInputStream$vtype _jc_java_io_LineNumberInputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_io_LineNumberInputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_io_LineNumberInputStream$class_object;

#endif	/* _JC_java_io_LineNumberInputStream_H_ */
